@@ -13,9 +13,11 @@
  * Note that quite interesting alg. is for preparing dithering table at
  * fixedcolor displays.
  */
-#ifndef _plan9_
-#include <malloc.h>
 #include <config.h>
+#ifndef _plan9_
+#ifndef NO_MALLOC_H
+#include <malloc.h>
+#endif
 #include <stdio.h>
 #include <string.h>
 #ifdef HAVE_ALLOCA_H
@@ -29,11 +31,12 @@
 #endif
 #include <fconfig.h>
 #include <filter.h>
+#include <xerror.h>
 #include <fractal.h>
 #include <xthread.h>
+#include <archaccel.h>
 #define MSIZE 8
-static int matrix[MSIZE][MSIZE] =
-{
+static CONST unsigned char matrix[MSIZE][MSIZE] = {
   {0, 192, 48, 240, 12, 204, 60, 252,},
   {128, 64, 176, 112, 140, 76, 188, 124,},
   {32, 224, 16, 208, 44, 236, 28, 220,},
@@ -44,44 +47,45 @@ static int matrix[MSIZE][MSIZE] =
   {168, 104, 152, 88, 164, 100, 148, 84},
 };
 struct ditherdata
-  {
-    unsigned char table[32][32][32];
-    int rmat[MSIZE][MSIZE];
-    int gmat[MSIZE][MSIZE];
-    int bmat[MSIZE][MSIZE];
-    struct palette *palette;
-    int active;
-  };
+{
+  unsigned char table[32][32][32];
+  int rmat[MSIZE][MSIZE];
+  int gmat[MSIZE][MSIZE];
+  int bmat[MSIZE][MSIZE];
+  struct palette *palette;
+  int active;
+};
 struct fixeddata
-  {
-    /*6kKb of table */
-    unsigned char ctable[8][8][256];
-    /*and 32kB */
-    unsigned char table[32][32][32];
-    /*and 768 bytes... */
-    int rmat[MSIZE][MSIZE];
-    int gmat[MSIZE][MSIZE];
-    int bmat[MSIZE][MSIZE];
-    struct palette *palette;
-    int forversion;
-    int active;
-    int fixcolor;
-  };
+{
+  /*6kKb of table */
+  unsigned char ctable[8][8][256];
+  /*and 32kB */
+  unsigned char table[32][32][32];
+  /*and 768 bytes... */
+  int rmat[MSIZE][MSIZE];
+  int gmat[MSIZE][MSIZE];
+  int bmat[MSIZE][MSIZE];
+  struct palette *palette;
+  int forversion;
+  int active;
+  int fixcolor;
+};
 struct bitmapdata
-  {
-    struct palette *palette;
-    int intensity[256];
-    int forversion;
-    int active;
-    int fixcolor;
-  };
+{
+  struct palette *palette;
+  int intensity[256];
+  int forversion;
+  int active;
+  int fixcolor;
+};
 static int
 requirement (struct filter *f, struct requirements *r)
 {
   f->req = *r;
   r->nimages = 1;
   r->flags &= ~IMAGEDATA;
-  r->supportedmask = FIXEDCOLOR | MASK1BPP | MASK3BPP | MASK2BPP | MASK4BPP | BITMAPS;
+  r->supportedmask =
+    FIXEDCOLOR | MASK1BPP | MASK3BPP | MASK2BPP | MASK4BPP | BITMAPS;
   return (f->next->action->requirement (f->next, r));
 }
 
@@ -123,9 +127,9 @@ requirement (struct filter *f, struct requirements *r)
 ((((int)(r)) / 8) * 32 * 32 + (((int)(g)) / 8) * 32 + (((int)(b)) / 8))
 
 #define depos(pal, r, g, b) \
-  ((b) = ((pal) & 31) * 8, \
-   (g) = (((pal) >> 5) & 31) * 8, \
-   (r) = (((pal) >> 10) & 31) * 8)
+  ((b) = ((unsigned int)(pal) & 31) * 8, \
+   (g) = (((unsigned int)(pal) >> 5) & 31) * 8, \
+   (r) = (((unsigned int)(pal) >> 10) & 31) * 8)
 
   /* is current color better than pal1? */
 #define better(r1, g1, b1, pal1) \
@@ -152,7 +156,7 @@ requirement (struct filter *f, struct requirements *r)
       } \
   }
 
-void
+static void
 create_rgb_table (unsigned char table[32][32][32], struct palette *palette)
 {
   int i, curr, r, g, b, val, r2, g2, b2, dist2;
@@ -163,12 +167,12 @@ create_rgb_table (unsigned char table[32][32][32], struct palette *palette)
   int last = LAST;
   int count = 0;
 
-  next=malloc(sizeof(short)*32*32*32);
+  next = (unsigned short *) malloc (sizeof (short) * 32 * 32 * 32);
   if (col_diff[0][1] == 0)
     bestfit_init ();
 
-  memset (next, 255, sizeof (short)*32*32*32);
-  memset (table, palette->start, sizeof (char) * 32 * 32 * 32);
+  memset_long (next, 255, sizeof (short) * 32 * 32 * 32);
+  memset_long (table, palette->start, sizeof (char) * 32 * 32 * 32);
   depos (32 * 32 * 32 - 1, r, g, b);
 
   data = (unsigned char *) table;
@@ -179,7 +183,7 @@ create_rgb_table (unsigned char table[32][32][32], struct palette *palette)
       curr = pos ((int) pal[i][0], (int) pal[i][1], (int) pal[i][2]);
       if (next[curr] == UNUSED)
 	{
-	  data[curr] = i;
+	  data[curr] = (unsigned int) i;
 	  add (curr);
 	}
     }
@@ -261,10 +265,11 @@ create_rgb_table (unsigned char table[32][32][32], struct palette *palette)
 
       count++;
     }
-  free(next);
+  free (next);
 }
 static void
-checksizes (unsigned char table[32][32][32], int *red, int *green, int *blue)
+checksizes (unsigned char table[32][32][32], int *RESTRICT red,
+	    int *RESTRICT green, int *RESTRICT blue)
 {
   int r, g, b;
   int color;
@@ -328,14 +333,15 @@ checksizes (unsigned char table[32][32][32], int *red, int *green, int *blue)
 static int
 initialize (struct filter *f, struct initdata *i)
 {
-  struct ditherdata *s = f->data;
+  struct ditherdata *s = (struct ditherdata *) f->data;
   struct palette *palette;
   int r, g, b;
   inhermisc (f, i);
   if (i->image->bytesperpixel <= 1)
     {
       int red, green, blue;
-      if (!inherimage (f, i, TOUCHIMAGE /*| IMAGEDATA*/, 0, 0, s->palette, 0, 0))
+      if (!inherimage
+	  (f, i, TOUCHIMAGE /*| IMAGEDATA */ , 0, 0, s->palette, 0, 0))
 	return 0;
       if (!s->active)
 	{
@@ -354,14 +360,24 @@ initialize (struct filter *f, struct initdata *i)
 	    for (g = 0; g < 32; g++)
 	      for (b = 0; b < 32; b++)
 		{
-		  s->table[r][g][b] = f->image->palette->pixels[((r * red + red / 2) / 32) + ((g * green + green / 2) / 32) * blue * red + ((b * blue + blue / 2) / 32) * red];
+		  s->table[r][g][b] =
+		    f->image->palette->pixels[((r * red + red / 2) / 32) +
+					      ((g * green +
+						green / 2) / 32) * blue *
+					      red +
+					      ((b * blue +
+						blue / 2) / 32) * red];
 		}
 	  for (r = 0; r < MSIZE; r++)
 	    for (g = 0; g < MSIZE; g++)
 	      {
-		s->rmat[r][g] = (matrix[r][g] - 128) * 256 / red / 256;
-		s->gmat[r][g] = (matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] - 128) * 256 / green / 256;
-		s->bmat[r][g] = (matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] - 128) * 256 / blue / 256;
+		s->rmat[r][g] = ((int) matrix[r][g] - 128) * 256 / red / 256;
+		s->gmat[r][g] =
+		  ((int) matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] -
+		   128) * 256 / green / 256;
+		s->bmat[r][g] =
+		  ((int) matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] -
+		   128) * 256 / blue / 256;
 	      }
 	  break;
 #ifdef SFIXEDCOLOR
@@ -371,9 +387,13 @@ initialize (struct filter *f, struct initdata *i)
 	  for (r = 0; r < MSIZE; r++)
 	    for (g = 0; g < MSIZE; g++)
 	      {
-		s->rmat[r][g] = (matrix[r][g] - 128) * red / 256;
-		s->gmat[r][g] = (matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] - 128) * green / 256;
-		s->bmat[r][g] = (matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] - 128) * blue / 256;
+		s->rmat[r][g] = ((int) matrix[r][g] - 128) * red / 256;
+		s->gmat[r][g] =
+		  ((int) matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] -
+		   128) * green / 256;
+		s->bmat[r][g] =
+		  ((int) matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] -
+		   128) * blue / 256;
 	      }
 	  break;
 #endif
@@ -387,8 +407,7 @@ initialize (struct filter *f, struct initdata *i)
 	case GRAYSCALE:
 	  break;
 	default:
-	  printf ("Unsupported image type. Recompile XaoS\n");
-	  exit (-1);
+	  x_fatalerror ("Unsupported image type. Recompile XaoS.");
 	}
       setfractalpalette (f, s->palette);
       s->active = 1;
@@ -399,6 +418,7 @@ initialize (struct filter *f, struct initdata *i)
     {
       if (s->active)
 	{
+	  f->image = i->image;
 	  palette = clonepalette (s->palette);
 	  restorepalette (f->image->palette, palette);
 	  destroypalette (palette);
@@ -408,11 +428,13 @@ initialize (struct filter *f, struct initdata *i)
     }
 }
 static struct filter *
-getinstance (struct filteraction *a)
+getinstance (CONST struct filteraction *a)
 {
   struct filter *f = createfilter (a);
-  struct ditherdata *i = calloc (sizeof (*i), 1);
-  i->palette = createpalette (0, 65536, TRUECOLOR, 0, 65536, NULL, NULL, NULL, NULL);
+  struct ditherdata *i = (struct ditherdata *) calloc (1, sizeof (*i));
+  i->palette =
+    createpalette (0, 65536, TRUECOLOR, 0, 65536, NULL, NULL, NULL, NULL,
+		   NULL);
   f->data = i;
   f->name = "Truecolor to 8bpp convertor";
   return (f);
@@ -420,13 +442,13 @@ getinstance (struct filteraction *a)
 static void
 convert (void *data, struct taskinfo *task, int r1, int r2)
 {
-  struct filter *f = data;
-  struct image *img1 = f->childimage;
-  struct image *img2 = f->image;
-  struct ditherdata *s = f->data;
-  pixel32_t *src, *srcend;
+  struct filter *RESTRICT f = (struct filter *) data;
+  struct image *RESTRICT img1 = f->childimage;
+  struct image *RESTRICT img2 = f->image;
+  CONST struct ditherdata *RESTRICT s = (struct ditherdata *) f->data;
+  CONST pixel32_t *RESTRICT src, *srcend;
   int r, g, b;
-  pixel8_t *dest;
+  pixel8_t *RESTRICT dest;
   int i;
   int x = 0;
 
@@ -446,33 +468,37 @@ convert (void *data, struct taskinfo *task, int r1, int r2)
 	  r += s->rmat[x][(unsigned long) dest & (MSIZE - 1)];
 	  g += s->gmat[x][(unsigned long) dest & (MSIZE - 1)];
 	  b += s->bmat[x][(unsigned long) dest & (MSIZE - 1)];
-	  if (r & (~255)) {
-	    if (r < 0)
-	      r = 0;
-	    else if (r > 255)
-	      r = 255;
-	  }
-	  if (g & (~255)) {
-	    if (g < 0)
-	      g = 0;
-	    else if (g > 255)
-	      g = 255;
-	  }
-	  if (b & (~255)) {
-	    if (b < 0)
-	      b = 0;
-	    else if (b > 255)
-	      b = 255;
-	  }
+	  if (r & (~255))
+	    {
+	      if (r < 0)
+		r = 0;
+	      else if (r > 255)
+		r = 255;
+	    }
+	  if (g & (~255))
+	    {
+	      if (g < 0)
+		g = 0;
+	      else if (g > 255)
+		g = 255;
+	    }
+	  if (b & (~255))
+	    {
+	      if (b < 0)
+		b = 0;
+	      else if (b > 255)
+		b = 255;
+	    }
 	  *dest = s->table[r >> 3][g >> 3][b >> 3];
 	}
     }
 }
+
 #define intenzity(x) ((int)(((x)&255) * 76 + (((x)>>8)&255) * 151 + (((x)>>16)&255) * 28)>>8)
 static void
 convertgray (void *data, struct taskinfo *task, int r1, int r2)
 {
-  struct filter *f = data;
+  struct filter *f = (struct filter *) data;
   struct image *img1 = f->childimage;
   struct image *img2 = f->image;
   pixel32_t *src, *srcend;
@@ -481,7 +507,9 @@ convertgray (void *data, struct taskinfo *task, int r1, int r2)
   int x = 0;
   unsigned char table[256];
   for (i = 0; i < 256; i++)
-    table[i] = i * (img2->palette->end - img2->palette->start) / 256 + img2->palette->start;
+    table[i] =
+      i * (img2->palette->end - img2->palette->start) / 256 +
+      img2->palette->start;
 
   for (i = r1; i < r2; i++)
     {
@@ -496,12 +524,13 @@ convertgray (void *data, struct taskinfo *task, int r1, int r2)
 	}
     }
 }
+
 #ifdef SBITMAPS
 #define inten(x) ((int)(((x)&255) * 76 + (((x)>>8)&255) * 151 + (((x)>>16)&255) * 28)>>8)-256
 static void
 converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 {
-  struct filter *f = data;
+  struct filter *f = (struct filter *) data;
   struct image *img1 = f->childimage;
   struct image *img2 = f->image;
   pixel32_t *src, *srcend;
@@ -523,23 +552,23 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case MBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (inten (src[0]) + matrix[x][0] >= 0)
+	      if (inten (src[0]) + (int) matrix[x][0] >= 0)
 		val = 128;
 	      else
 		val = 0;
-	      if (inten (src[1]) + matrix[x][1] >= 0)
+	      if (inten (src[1]) + (int) matrix[x][1] >= 0)
 		val |= 64;
-	      if (inten (src[2]) + matrix[x][2] >= 0)
+	      if (inten (src[2]) + (int) matrix[x][2] >= 0)
 		val |= 32;
-	      if (inten (src[3]) + matrix[x][3] >= 0)
+	      if (inten (src[3]) + (int) matrix[x][3] >= 0)
 		val |= 16;
-	      if (inten (src[4]) + matrix[x][4] >= 0)
+	      if (inten (src[4]) + (int) matrix[x][4] >= 0)
 		val |= 8;
-	      if (inten (src[5]) + matrix[x][5] >= 0)
+	      if (inten (src[5]) + (int) matrix[x][5] >= 0)
 		val |= 4;
-	      if (inten (src[6]) + matrix[x][6] >= 0)
+	      if (inten (src[6]) + (int) matrix[x][6] >= 0)
 		val |= 2;
-	      if (inten (src[7]) + matrix[x][7] >= 0)
+	      if (inten (src[7]) + (int) matrix[x][7] >= 0)
 		val |= 1;
 	      src += 8;
 	      *dest = val;
@@ -550,7 +579,7 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 128; src < srcend; mask >>= 1, src++, y++)
 		{
-		  if (inten (*src) + matrix[x][y] >= 0)
+		  if (inten (*src) + (int) matrix[x][y] >= 0)
 		    val |= mask;
 		}
 	      if (!mask)
@@ -560,23 +589,23 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case MIBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (inten (src[0]) + matrix[x][0] <= 0)
+	      if (inten (src[0]) + (int) matrix[x][0] <= 0)
 		val = 128;
 	      else
 		val = 0;
-	      if (inten (src[1]) + matrix[x][1] <= 0)
+	      if (inten (src[1]) + (int) matrix[x][1] <= 0)
 		val |= 64;
-	      if (inten (src[2]) + matrix[x][2] <= 0)
+	      if (inten (src[2]) + (int) matrix[x][2] <= 0)
 		val |= 32;
-	      if (inten (src[3]) + matrix[x][3] <= 0)
+	      if (inten (src[3]) + (int) matrix[x][3] <= 0)
 		val |= 16;
-	      if (inten (src[4]) + matrix[x][4] <= 0)
+	      if (inten (src[4]) + (int) matrix[x][4] <= 0)
 		val |= 8;
-	      if (inten (src[5]) + matrix[x][5] <= 0)
+	      if (inten (src[5]) + (int) matrix[x][5] <= 0)
 		val |= 4;
-	      if (inten (src[6]) + matrix[x][6] <= 0)
+	      if (inten (src[6]) + (int) matrix[x][6] <= 0)
 		val |= 2;
-	      if (inten (src[7]) + matrix[x][7] <= 0)
+	      if (inten (src[7]) + (int) matrix[x][7] <= 0)
 		val |= 1;
 	      src += 8;
 	      *dest = val;
@@ -587,7 +616,7 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 128; src < srcend; mask >>= 1, src++, y++)
 		{
-		  if (inten (*src) + matrix[x][y] <= 0)
+		  if (inten (*src) + (int) matrix[x][y] <= 0)
 		    val |= mask;
 		}
 	      if (!mask)
@@ -599,23 +628,23 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case LBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (inten (src[0]) + matrix[x][0] >= 0)
+	      if (inten (src[0]) + (int) matrix[x][0] >= 0)
 		val = 1;
 	      else
 		val = 0;
-	      if (inten (src[1]) + matrix[x][1] >= 0)
+	      if (inten (src[1]) + (int) matrix[x][1] >= 0)
 		val |= 2;
-	      if (inten (src[2]) + matrix[x][2] >= 0)
+	      if (inten (src[2]) + (int) matrix[x][2] >= 0)
 		val |= 4;
-	      if (inten (src[3]) + matrix[x][3] >= 0)
+	      if (inten (src[3]) + (int) matrix[x][3] >= 0)
 		val |= 8;
-	      if (inten (src[4]) + matrix[x][4] >= 0)
+	      if (inten (src[4]) + (int) matrix[x][4] >= 0)
 		val |= 16;
-	      if (inten (src[5]) + matrix[x][5] >= 0)
+	      if (inten (src[5]) + (int) matrix[x][5] >= 0)
 		val |= 32;
-	      if (inten (src[6]) + matrix[x][6] >= 0)
+	      if (inten (src[6]) + (int) matrix[x][6] >= 0)
 		val |= 64;
-	      if (inten (src[7]) + matrix[x][7] >= 0)
+	      if (inten (src[7]) + (int) matrix[x][7] >= 0)
 		val |= 128;
 	      src += 8;
 	      *dest = val;
@@ -626,7 +655,7 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 1; src < srcend; mask <<= 1, src++, y++)
 		{
-		  if (inten (*src) + matrix[x][y] >= 0)
+		  if (inten (*src) + (int) matrix[x][y] >= 0)
 		    val |= mask;
 		}
 	      if (!mask)
@@ -636,23 +665,23 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case LIBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (inten (src[0]) + matrix[x][0] <= 0)
+	      if (inten (src[0]) + (int) matrix[x][0] <= 0)
 		val = 1;
 	      else
 		val = 0;
-	      if (inten (src[1]) + matrix[x][1] <= 0)
+	      if (inten (src[1]) + (int) matrix[x][1] <= 0)
 		val |= 2;
-	      if (inten (src[2]) + matrix[x][2] <= 0)
+	      if (inten (src[2]) + (int) matrix[x][2] <= 0)
 		val |= 4;
-	      if (inten (src[3]) + matrix[x][3] <= 0)
+	      if (inten (src[3]) + (int) matrix[x][3] <= 0)
 		val |= 8;
-	      if (inten (src[4]) + matrix[x][4] <= 0)
+	      if (inten (src[4]) + (int) matrix[x][4] <= 0)
 		val |= 16;
-	      if (inten (src[5]) + matrix[x][5] <= 0)
+	      if (inten (src[5]) + (int) matrix[x][5] <= 0)
 		val |= 32;
-	      if (inten (src[6]) + matrix[x][6] <= 0)
+	      if (inten (src[6]) + (int) matrix[x][6] <= 0)
 		val |= 64;
-	      if (inten (src[7]) + matrix[x][7] <= 0)
+	      if (inten (src[7]) + (int) matrix[x][7] <= 0)
 		val |= 128;
 	      src += 8;
 	      *dest = val;
@@ -663,7 +692,7 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 1; src < srcend; mask <<= 1, src++, y++)
 		{
-		  if (inten (*src) + matrix[x][y] <= 0)
+		  if (inten (*src) + (int) matrix[x][y] <= 0)
 		    val |= mask;
 		}
 	      if (!mask)
@@ -679,7 +708,7 @@ converttbitmap (void *data, struct taskinfo *task, int r1, int r2)
 static void
 destroyinstance (struct filter *f)
 {
-  struct ditherdata *i = f->data;
+  struct ditherdata *i = (struct ditherdata *) f->data;
   destroypalette (i->palette);
   free (f->data);
   destroyinheredimage (f);
@@ -689,7 +718,7 @@ static int
 doit (struct filter *f, int flags, int time)
 {
   int val;
-  struct ditherdata *s = f->data;
+  struct ditherdata *s = (struct ditherdata *) f->data;
   if (s->active)
     updateinheredimage (f);
   val = f->previous->action->doit (f->previous, flags, time);
@@ -716,7 +745,7 @@ doit (struct filter *f, int flags, int time)
 static void
 myremovefilter (struct filter *f)
 {
-  struct ditherdata *s = f->data;
+  struct ditherdata *s = (struct ditherdata *) f->data;
   struct palette *palette;
   if (s->active)
     {
@@ -727,8 +756,7 @@ myremovefilter (struct filter *f)
 }
 
 
-struct filteraction truecolor_filter =
-{
+CONST struct filteraction truecolor_filter = {
   "Truecolor emulator",
   "truecolor",
   0,
@@ -748,14 +776,14 @@ struct filteraction truecolor_filter =
 static int
 myfixedalloccolor (struct palette *p, int init, int r, int g, int b)
 {
-  struct palette *palette = p->data;
+  struct palette *palette = (struct palette *) p->data;
   fixedalloccolor (p, init, r, g, b);
   return (palette->alloccolor (palette, init, r, g, b));
 }
 static void
 myallocfinished (struct palette *p)
 {
-  struct palette *palette = p->data;
+  struct palette *palette = (struct palette *) p->data;
   palette->allocfinished (palette);
 }
 static void
@@ -769,11 +797,12 @@ mysetcolor (struct palette *p, int start, int end, rgb_t * rgb)
 static int
 initializefixed (struct filter *f, struct initdata *i)
 {
-  struct fixeddata *s = f->data;
+  struct fixeddata *s = (struct fixeddata *) f->data;
   struct palette *palette;
   int r, g;
   inhermisc (f, i);
-  if (i->image->palette->type == FIXEDCOLOR && !(f->req.supportedmask & FIXEDCOLOR))
+  if (i->image->palette->type == FIXEDCOLOR
+      && !(f->req.supportedmask & FIXEDCOLOR))
     {
       int red, green, blue;
       i->image->palette->alloccolor = myfixedalloccolor;
@@ -792,9 +821,13 @@ initializefixed (struct filter *f, struct initdata *i)
       for (r = 0; r < MSIZE; r++)
 	for (g = 0; g < MSIZE; g++)
 	  {
-	    s->rmat[r][g] = (matrix[r][g] - 128) * red / 256;
-	    s->gmat[r][g] = (matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] - 128) * green / 256;
-	    s->bmat[r][g] = (matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] - 128) * blue / 256;
+	    s->rmat[r][g] = ((int) matrix[r][g] - 128) * red / 256;
+	    s->gmat[r][g] =
+	      ((int) matrix[(r + 3) % MSIZE][(g + 6) % MSIZE] -
+	       128) * green / 256;
+	    s->bmat[r][g] =
+	      ((int) matrix[(r + 6) % MSIZE][(g + 3) % MSIZE] -
+	       128) * blue / 256;
 	  }
       s->palette->data = &s->palette;
       setfractalpalette (f, s->palette);
@@ -814,11 +847,12 @@ initializefixed (struct filter *f, struct initdata *i)
     }
 }
 static struct filter *
-getinstancefixed (struct filteraction *a)
+getinstancefixed (CONST struct filteraction *a)
 {
   struct filter *f = createfilter (a);
-  struct fixeddata *i = calloc (sizeof (*i), 1);
-  i->palette = createpalette (0, 256, C256, 0, 256, NULL, mysetcolor, NULL, NULL);
+  struct fixeddata *i = (struct fixeddata *) calloc (1, sizeof (*i));
+  i->palette =
+    createpalette (0, 256, C256, 0, 256, NULL, mysetcolor, NULL, NULL, NULL);
   i->active = -1;
   f->data = i;
   f->name = "Palete emulator";
@@ -827,10 +861,10 @@ getinstancefixed (struct filteraction *a)
 static void
 convertfixed (void *data, struct taskinfo *task, int r1, int r2)
 {
-  struct filter *f = data;
+  struct filter *f = (struct filter *) data;
   struct image *img1 = f->childimage;
   struct image *img2 = f->image;
-  struct fixeddata *s = f->data;
+  struct fixeddata *s = (struct fixeddata *) f->data;
   pixel8_t *src, *srcend;
   pixel8_t *dest;
   int i;
@@ -852,7 +886,7 @@ static int
 doitfixed (struct filter *f, int flags, int time)
 {
   int val;
-  struct fixeddata *s = f->data;
+  struct fixeddata *s = (struct fixeddata *) f->data;
   if (s->fixcolor && !s->active)
     {
       struct palette *palette;
@@ -881,26 +915,29 @@ doitfixed (struct filter *f, int flags, int time)
 		  {
 		    int r, g, b;
 		    r = s->palette->rgb[i][0] + s->rmat[x][y];
-		    if (r & (~255)) {
-		      if (r < 0)
-			r = 0;
-		      else if (r > 255)
-			r = 255;
-		    }
+		    if (r & (~255))
+		      {
+			if (r < 0)
+			  r = 0;
+			else if (r > 255)
+			  r = 255;
+		      }
 		    g = s->palette->rgb[i][1] + s->gmat[x][y];
-		    if (g & (~255)) {
-		      if (g < 0)
-			g = 0;
-		      else if (g > 255)
-			g = 255;
-		    }
+		    if (g & (~255))
+		      {
+			if (g < 0)
+			  g = 0;
+			else if (g > 255)
+			  g = 255;
+		      }
 		    b = s->palette->rgb[i][2] + s->bmat[x][y];
-		    if (b & (~255)) {
-		      if (b < 0)
-			b = 0;
-		      else if (b > 255)
-			b = 255;
-		    }
+		    if (b & (~255))
+		      {
+			if (b < 0)
+			  b = 0;
+			else if (b > 255)
+			  b = 255;
+		      }
 		    s->ctable[x][y][i] = s->table[r >> 3][g >> 3][b >> 3];
 		  }
 	    }
@@ -913,7 +950,7 @@ doitfixed (struct filter *f, int flags, int time)
 static void
 myremovefilterfixed (struct filter *f)
 {
-  struct fixeddata *s = f->data;
+  struct fixeddata *s = (struct fixeddata *) f->data;
   struct palette *palette;
   if (s->active)
     {
@@ -925,14 +962,13 @@ myremovefilterfixed (struct filter *f)
 static void
 destroyinstancefixed (struct filter *f)
 {
-  struct fixeddata *i = f->data;
+  struct fixeddata *i = (struct fixeddata *) f->data;
   destroypalette (i->palette);
   free (f->data);
   destroyinheredimage (f);
   free (f);
 }
-struct filteraction fixedcolor_filter =
-{
+CONST struct filteraction fixedcolor_filter = {
   "Palette emulator",
   "fixedcolor",
   0,
@@ -951,10 +987,11 @@ struct filteraction fixedcolor_filter =
 static int
 initializebitmap (struct filter *f, struct initdata *i)
 {
-  struct bitmapdata *s = f->data;
+  struct bitmapdata *s = (struct bitmapdata *) f->data;
   struct palette *palette;
   inhermisc (f, i);
-  if ((i->image->palette->type & BITMAPS) && !(f->req.supportedmask & BITMAPS))
+  if ((i->image->palette->type & BITMAPS)
+      && !(f->req.supportedmask & BITMAPS))
     {
       i->image->palette->alloccolor = myfixedalloccolor;
       i->image->palette->allocfinished = myallocfinished;
@@ -985,24 +1022,26 @@ initializebitmap (struct filter *f, struct initdata *i)
     }
 }
 static struct filter *
-getinstancebitmap (struct filteraction *a)
+getinstancebitmap (CONST struct filteraction *a)
 {
   struct filter *f = createfilter (a);
-  struct bitmapdata *i = calloc (sizeof (*i), 1);
-  i->palette = createpalette (0, 256, C256, 0, 256, NULL, mysetcolor, NULL, NULL);
+  struct bitmapdata *i = (struct bitmapdata *) calloc (1, sizeof (*i));
+  i->palette =
+    createpalette (0, 256, C256, 0, 256, NULL, mysetcolor, NULL, NULL, NULL);
   i->active = -1;
   f->data = i;
   f->name = "Palete emulator";
   return (f);
 }
+
 #define INTENSITY(r,g,b) (r * 30U + g * 59U + b * 11U)/100U-256U
 static void
 convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 {
-  struct filter *f = data;
+  struct filter *f = (struct filter *) data;
   struct image *img1 = f->childimage;
   struct image *img2 = f->image;
-  struct bitmapdata *s = f->data;
+  struct bitmapdata *s = (struct bitmapdata *) f->data;
   pixel8_t *src, *srcend;
   pixel8_t *dest = NULL;
   int *intensity = s->intensity;
@@ -1023,23 +1062,23 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case MBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (intensity[src[0]] + matrix[x][0] >= 0)
+	      if (intensity[src[0]] + (int) matrix[x][0] >= 0)
 		val = 128;
 	      else
 		val = 0;
-	      if (intensity[src[1]] + matrix[x][1] >= 0)
+	      if (intensity[src[1]] + (int) matrix[x][1] >= 0)
 		val |= 64;
-	      if (intensity[src[2]] + matrix[x][2] >= 0)
+	      if (intensity[src[2]] + (int) matrix[x][2] >= 0)
 		val |= 32;
-	      if (intensity[src[3]] + matrix[x][3] >= 0)
+	      if (intensity[src[3]] + (int) matrix[x][3] >= 0)
 		val |= 16;
-	      if (intensity[src[4]] + matrix[x][4] >= 0)
+	      if (intensity[src[4]] + (int) matrix[x][4] >= 0)
 		val |= 8;
-	      if (intensity[src[5]] + matrix[x][5] >= 0)
+	      if (intensity[src[5]] + (int) matrix[x][5] >= 0)
 		val |= 4;
-	      if (intensity[src[6]] + matrix[x][6] >= 0)
+	      if (intensity[src[6]] + (int) matrix[x][6] >= 0)
 		val |= 2;
-	      if (intensity[src[7]] + matrix[x][7] >= 0)
+	      if (intensity[src[7]] + (int) matrix[x][7] >= 0)
 		val |= 1;
 	      src += 8;
 	      *dest = val;
@@ -1050,7 +1089,7 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 128; src < srcend; mask >>= 1, src++, y++)
 		{
-		  if (intensity[*src] + matrix[x][y] >= 0)
+		  if (intensity[*src] + (int) matrix[x][y] >= 0)
 		    val |= mask;
 		}
 	      *dest = val, dest++;
@@ -1059,23 +1098,23 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case MIBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (intensity[src[0]] + matrix[x][0] <= 0)
+	      if (intensity[src[0]] + (int) matrix[x][0] <= 0)
 		val = 128;
 	      else
 		val = 0;
-	      if (intensity[src[1]] + matrix[x][1] <= 0)
+	      if (intensity[src[1]] + (int) matrix[x][1] <= 0)
 		val |= 64;
-	      if (intensity[src[2]] + matrix[x][2] <= 0)
+	      if (intensity[src[2]] + (int) matrix[x][2] <= 0)
 		val |= 32;
-	      if (intensity[src[3]] + matrix[x][3] <= 0)
+	      if (intensity[src[3]] + (int) matrix[x][3] <= 0)
 		val |= 16;
-	      if (intensity[src[4]] + matrix[x][4] <= 0)
+	      if (intensity[src[4]] + (int) matrix[x][4] <= 0)
 		val |= 8;
-	      if (intensity[src[5]] + matrix[x][5] <= 0)
+	      if (intensity[src[5]] + (int) matrix[x][5] <= 0)
 		val |= 4;
-	      if (intensity[src[6]] + matrix[x][6] <= 0)
+	      if (intensity[src[6]] + (int) matrix[x][6] <= 0)
 		val |= 2;
-	      if (intensity[src[7]] + matrix[x][7] <= 0)
+	      if (intensity[src[7]] + (int) matrix[x][7] <= 0)
 		val |= 1;
 	      src += 8;
 	      *dest = val;
@@ -1086,7 +1125,7 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 128; src < srcend; mask >>= 1, src++, y++)
 		{
-		  if (intensity[*src] + matrix[x][y] <= 0)
+		  if (intensity[*src] + (int) matrix[x][y] <= 0)
 		    val |= mask;
 		}
 	      *dest = val, dest++;
@@ -1097,23 +1136,23 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case LBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (intensity[src[0]] + matrix[x][0] >= 0)
+	      if (intensity[src[0]] + (int) matrix[x][0] >= 0)
 		val = 1;
 	      else
 		val = 0;
-	      if (intensity[src[1]] + matrix[x][1] >= 0)
+	      if (intensity[src[1]] + (int) matrix[x][1] >= 0)
 		val |= 2;
-	      if (intensity[src[2]] + matrix[x][2] >= 0)
+	      if (intensity[src[2]] + (int) matrix[x][2] >= 0)
 		val |= 4;
-	      if (intensity[src[3]] + matrix[x][3] >= 0)
+	      if (intensity[src[3]] + (int) matrix[x][3] >= 0)
 		val |= 8;
-	      if (intensity[src[4]] + matrix[x][4] >= 0)
+	      if (intensity[src[4]] + (int) matrix[x][4] >= 0)
 		val |= 16;
-	      if (intensity[src[5]] + matrix[x][5] >= 0)
+	      if (intensity[src[5]] + (int) matrix[x][5] >= 0)
 		val |= 32;
-	      if (intensity[src[6]] + matrix[x][6] >= 0)
+	      if (intensity[src[6]] + (int) matrix[x][6] >= 0)
 		val |= 64;
-	      if (intensity[src[7]] + matrix[x][7] >= 0)
+	      if (intensity[src[7]] + (int) matrix[x][7] >= 0)
 		val |= 128;
 	      src += 8;
 	      *dest = val;
@@ -1124,7 +1163,7 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 1; src < srcend; mask <<= 1, src++, y++)
 		{
-		  if (intensity[*src] + matrix[x][y] >= 0)
+		  if (intensity[*src] + (int) matrix[x][y] >= 0)
 		    val |= mask;
 		}
 	      *dest = val, dest++;
@@ -1132,23 +1171,23 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	case LIBITMAP:
 	  for (; src < srcend; dest++)
 	    {
-	      if (intensity[src[0]] + matrix[x][0] <= 0)
+	      if (intensity[src[0]] + (int) matrix[x][0] <= 0)
 		val = 1;
 	      else
 		val = 0;
-	      if (intensity[src[1]] + matrix[x][1] <= 0)
+	      if (intensity[src[1]] + (int) matrix[x][1] <= 0)
 		val |= 2;
-	      if (intensity[src[2]] + matrix[x][2] <= 0)
+	      if (intensity[src[2]] + (int) matrix[x][2] <= 0)
 		val |= 4;
-	      if (intensity[src[3]] + matrix[x][3] <= 0)
+	      if (intensity[src[3]] + (int) matrix[x][3] <= 0)
 		val |= 8;
-	      if (intensity[src[4]] + matrix[x][4] <= 0)
+	      if (intensity[src[4]] + (int) matrix[x][4] <= 0)
 		val |= 16;
-	      if (intensity[src[5]] + matrix[x][5] <= 0)
+	      if (intensity[src[5]] + (int) matrix[x][5] <= 0)
 		val |= 32;
-	      if (intensity[src[6]] + matrix[x][6] <= 0)
+	      if (intensity[src[6]] + (int) matrix[x][6] <= 0)
 		val |= 64;
-	      if (intensity[src[7]] + matrix[x][7] <= 0)
+	      if (intensity[src[7]] + (int) matrix[x][7] <= 0)
 		val |= 128;
 	      src += 8;
 	      *dest = val;
@@ -1159,7 +1198,7 @@ convertbitmap (void *data, struct taskinfo *task, int r1, int r2)
 	      y = 0;
 	      for (val = 0, mask = 1; src < srcend; mask <<= 1, src++, y++)
 		{
-		  if (intensity[*src] + matrix[x][y] <= 0)
+		  if (intensity[*src] + (int) matrix[x][y] <= 0)
 		    val |= mask;
 		}
 	      *dest = val, dest++;
@@ -1173,7 +1212,7 @@ static int
 doitbitmap (struct filter *f, int flags, int time)
 {
   int val;
-  struct bitmapdata *s = f->data;
+  struct bitmapdata *s = (struct bitmapdata *) f->data;
   if (s->fixcolor && !s->active)
     {
       struct palette *palette;
@@ -1207,7 +1246,7 @@ doitbitmap (struct filter *f, int flags, int time)
 static void
 myremovefilterbitmap (struct filter *f)
 {
-  struct bitmapdata *s = f->data;
+  struct bitmapdata *s = (struct bitmapdata *) f->data;
   struct palette *palette;
   if (s->active)
     {
@@ -1219,14 +1258,13 @@ myremovefilterbitmap (struct filter *f)
 static void
 destroyinstancebitmap (struct filter *f)
 {
-  struct bitmapdata *i = f->data;
+  struct bitmapdata *i = (struct bitmapdata *) f->data;
   destroypalette (i->palette);
   free (f->data);
   destroyinheredimage (f);
   free (f);
 }
-struct filteraction bitmap_filter =
-{
+CONST struct filteraction bitmap_filter = {
   "Palette emulator",
   "bitmap",
   0,
