@@ -251,6 +251,7 @@ static unsigned int
 truecolor_output (number_t zre, number_t zim, number_t pre, number_t pim,
 		  int mode, int inset)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int
        truecolor_output (number_t zre, number_t zim, number_t pre,
 			 number_t pim, int mode, int inset)
@@ -445,7 +446,8 @@ static unsigned int
 color_output (number_t zre, number_t zim, unsigned int iter)
      CONSTF REGISTERS (3);
      static unsigned int
-       color_output (number_t zre, number_t zim, unsigned int iter)
+       REGISTERS (3) color_output (number_t zre, number_t zim,
+				   unsigned int iter)
 {
   int i;
   iter <<= SHIFT;
@@ -529,6 +531,7 @@ static unsigned int
 incolor_output (number_t zre, number_t zim, number_t pre, number_t pim,
 		unsigned int iter)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int
        incolor_output (number_t zre, number_t zim, number_t pre, number_t pim,
 		       unsigned int iter)
@@ -861,6 +864,177 @@ pacalc (long double zre, long double zim, long double pre, long double pim)
 #define RPIP
 #include "docalc.c"
 
+/* formulas from here to the next comment are not tested under plan9 compiler */
+
+#define VARIABLES
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	zim=zre*zim+zim/2+pim; \
+	zre=(rp-ip+zre)/2+pre; \
+	rp=zre*zre; \
+	ip=zim*zim;
+#define SMOOTH
+#define SCALC strice_calc
+#define SPERI strice_peri
+#define CALC trice_calc
+#define PERI trice_peri
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES register number_t zor,zoi;
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	c_div(pre,pim,zre,zim,rp,ip); \
+	c_div(zre,zim,pre,pim,zor,zoi); \
+	zre=zor+rp; \
+	zim=zoi+ip; \
+	rp=zre*zre; \
+	ip=zim*zim;
+#define SMOOTH
+#define SCALC scatseye_calc
+#define SPERI scatseye_peri
+#define CALC catseye_calc
+#define PERI catseye_peri
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	    zim=(zim*zre)*(-2.0)+pim; \
+	    zre=rp-ip+pre; \
+            ip=zim*zim; \
+            rp=zre*zre;
+#define SMOOTH
+#define SCALC smbar_calc
+#define SPERI smbar_peri
+#define CALC mbar_calc
+#define PERI mbar_peri
+#define JULIA mbar_julia
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES
+#define INIT \
+	rp=zre;zre=pre;pre=rp; \
+        ip=zim;zim=pim;pim=ip;
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	rp=ip-rp+zre; \
+	ip=zim-2*zre*zim; \
+	c_mul(rp,ip,pre,pim,zre,zim); \
+	rp=zre*zre; \
+	ip=zim*zim;
+#define SMOOTH
+#define SCALC smlambda_calc
+#define SPERI smlambda_peri
+#define CALC mlambda_calc
+#define PERI mlambda_peri
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES register number_t zre1,zim1,zre2,zim2;
+#define INIT zre1=zre;zim1=zim;
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	zre2=zre;zim2=zim; \
+	zim=(zim*zre)*2+pim+zim1; \
+	zre=rp-ip+pre+zre1; \
+	zre1=zre2; \
+	zim1=zim2; \
+	ip=zim*zim; \
+	rp=zre*zre;
+#define SMOOTH
+#define SCALC smanowar_calc
+#define CALC manowar_calc
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES register number_t zre1,zim1;
+#define INIT zre1=pre;zim1=pim;
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	zim=(zim*zre)*2+zim1; \
+	zre=rp-ip+zre1; \
+	zre1=zre1/2+zre; \
+	zim1=zim1/2+zim; \
+	ip=zim*zim; \
+	rp=zre*zre;	
+#define SMOOTH
+#define SCALC sspider_calc
+#define CALC spider_calc
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES
+#define INIT \
+	if((zre==pre)&&(zim==pim)){pre=0.5;pim=0.8660254;} \
+	if(pim<0)pim=(-pim); \
+	if(((pim*zre-pre*zim)<0)||(zim<0)){zre=2*pre+2;zim=2*pim;}
+#define BTEST ((pim*zre+(1-pre)*zim)<pim)
+#define FORMULA \
+	zre=2*zre;zim=2*zim; \
+	if((pim*zre-pre*zim)>pim)zre=zre-1; \
+	if(zim>pim){zim=zim-pim;zre=zre-pre;}
+#define CALC sier_calc
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES
+#define INIT \
+	if((zre==pre)&&(zim==pim)){pre=1;pim=1;} \
+	if(pre<0)pre=(-pre);if(pim<0)pim=(-pim); \
+	if((zre<0)||(zre>pre)){zre=pre/2;zim=pim/2;} \
+	if((zim<0)||(zim>pim)){zre=pre/2;zim=pim/2;}
+#define BTEST \
+	((zre<pre/3)||(zre>2*pre/3)|| \
+	(zim<pim/3)||(zim>2*pim/3))
+#define FORMULA \
+	zre=3*zre;zim=3*zim; \
+	if(zre>2*pre)zre=zre-2*pre;else if(zre>pre)zre=zre-pre; \
+	if(zim>2*pim)zim=zim-2*pim;else if(zim>pim)zim=zim-pim; 
+#define CALC carpet_calc
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
+#define VARIABLES
+#define BTEST \
+	((((1.5*zre+0.8660254038*zim)>0.8660254038)|| \
+	((0.8660254038*zim-1.5*zre)>0.8660254038)|| \
+	(zim<(-0.5)))&& \
+	(((1.5*zre+0.8660254038*zim)<-0.8660254038)|| \
+	((0.8660254038*zim-1.5*zre)<-0.8660254038)|| \
+	(zim>0.5)))
+#define FORMULA \
+	zre=3*zre;zim=3*zim; \
+	if((0.2886751346*zim-0.5*zre)>0.0){ \
+		if((0.2886751346*zim+0.5*zre)>0.0){ \
+			zim=zim-2.0;\
+		}else{ \
+			if(zim>0){zre=zre+1.732050808;zim=zim-1.0;} \
+			else{zre=zre+1.732050808;zim=zim+1.0;} \
+		} \
+	}else{ \
+		if((0.2886751346*zim+0.5*zre)<0.0){ \
+			zim=zim+2.0;\
+		}else{ \
+			if(zim>0){zre=zre-1.732050808;zim=zim-1.0;} \
+			else{zre=zre-1.732050808;zim=zim+1.0;} \
+		} \
+	} 
+#define CALC koch_calc
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
 /* plan9 compiler has problem with rest of formulas files. Hope that will be fixed later */
 
 #define VARIABLES
@@ -902,6 +1076,26 @@ pacalc (long double zre, long double zim, long double pre, long double pim)
 #define RPIP
 #include "docalc.c"
 
+#define VARIABLES
+#define BTEST less_than_4(rp+ip)
+#define FORMULA \
+	if (!less_than_0 (-zre)) { \
+		zim = 2*zre*zim + pim*zre; \
+		zre = rp - ip - 1 + pre*zre; \
+	} else { \
+		zim = 2*zre*zim; \
+		zre = rp - ip - 1; \
+	} \
+	rp = zre * zre; \
+	ip = zim * zim;
+#define SMOOTH
+#define SCALC sbarnsley3_calc
+#define CALC barnsley3_calc
+#define JULIA barnsley3_julia
+#define RANGE 2
+#define RPIP
+#include "docalc.c"
+
 
 #define VARIABLES register number_t n,sqrr,sqri,zre1,zim1;
 #define INIT sqri=zim*zim,n=zre,zre=pre,pre=n,n=zim,zim=pim,pim=n,n=(number_t)1;
@@ -1213,48 +1407,6 @@ CONST struct formula formulas[] = {
    },
   {
    FORMULAMAGIC,
-#ifndef SLOWFUNCPTR
-   octo_calc,
-   /*octo_peri, */ NULL,
-   socto_calc,
-   /*socto_peri, */ NULL,
-#endif
-   NULL,
-   {"Octal", "Octal"},
-   "octal",
-   /*{1.25, -1.25, 1.25, -1.25}, */
-   {0.0, 0.0, 2.5, 2.5},
-   0, 1, 0.0, 0.0,
-   {
-    {0, 0, 6, sym16},
-    {INT_MAX, 0, 0, NULL},
-    {0, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {0, INT_MAX, 0, NULL},
-    {0, 0, 0, NULL},
-    {0, 0, 6, sym16},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {0, 0, 6, sym16},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   {
-    {0, 0, 6, sym16},
-    {0, 0, 6, sym16},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   MANDEL_BTRACE | STARTZERO,
-   },
-  {
-   FORMULAMAGIC,
 #ifndef SLOWFUNCPTR
    newton_calc,
    NULL,
@@ -1295,6 +1447,48 @@ CONST struct formula formulas[] = {
     },
    STARTZERO,
    },
+  { /* formula added by Andreas Madritsch */
+   FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   newton4_calc,
+   NULL,
+   NULL,
+   NULL,
+#endif
+   NULL,
+   {"Newton^4", "Newton^4 julia?"},
+   "newton4",
+   /*{1.25, -1.25, 1.25, -1.25}, */
+   {0.0, 0.0, 2.5, 2.5},
+   0, 1, 1.0199502202048319698, 0.0,
+   {
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   STARTZERO,
+   },
   {
    FORMULAMAGIC,
 #ifndef SLOWFUNCPTR
@@ -1337,6 +1531,132 @@ CONST struct formula formulas[] = {
     },
    STARTZERO | MANDEL_BTRACE,
    },
+  { /* formula added by Andreas Madritsch */
+   FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   barnsley2_calc,
+   NULL,
+   sbarnsley2_calc,
+   NULL,
+#endif
+   barnsley2_julia,
+   {"Barnsley2 Mandelbrot", "Barnsley2"},
+   "barnsley2",
+   /*{1.25, -1.25, 1.25, -1.25}, */
+   {0.0, 0.0, 2.5, 5.5},
+   0, 0, -0.6, 1.1,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   STARTZERO | MANDEL_BTRACE,
+   },
+  { /* formula added by Arpad Fekete */
+   FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   barnsley3_calc,
+   NULL,
+   sbarnsley3_calc,
+   NULL,
+#endif
+   barnsley3_julia,
+   {"Barnsley3 Mandelbrot", "Barnsley3"},
+   "barnsley3",
+   /*{1.25, -1.25, 1.25, -1.25}, */
+   {0.0, 0.0, 2.5, 3.5},
+   0, 0, 0.0, 0.4,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   STARTZERO | MANDEL_BTRACE,
+   },
+  {
+   FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   octo_calc,
+   /*octo_peri, */ NULL,
+   socto_calc,
+   /*socto_peri, */ NULL,
+#endif
+   NULL,
+   {"Octal", "Octal"},
+   "octal",
+   /*{1.25, -1.25, 1.25, -1.25}, */
+   {0.0, 0.0, 2.5, 2.5},
+   0, 1, 0.0, 0.0,
+   {
+    {0, 0, 6, sym16},
+    {INT_MAX, 0, 0, NULL},
+    {0, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {0, INT_MAX, 0, NULL},
+    {0, 0, 0, NULL},
+    {0, 0, 6, sym16},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {0, 0, 6, sym16},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {0, 0, 6, sym16},
+    {0, 0, 6, sym16},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   MANDEL_BTRACE | STARTZERO,
+   },
   {
    FORMULAMAGIC,
 #ifndef SLOWFUNCPTR
@@ -1421,92 +1741,7 @@ CONST struct formula formulas[] = {
     },
    STARTZERO,
    },
-/* formulas added by Andreas Madritsch */
-  {
-   FORMULAMAGIC,
-#ifndef SLOWFUNCPTR
-   newton4_calc,
-   NULL,
-   NULL,
-   NULL,
-#endif
-   NULL,
-   {"Newton^4", "Newton^4 julia?"},
-   "newton4",
-   /*{1.25, -1.25, 1.25, -1.25}, */
-   {0.0, 0.0, 2.5, 2.5},
-   0, 1, 1.0199502202048319698, 0.0,
-   {
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, 0, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   {
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, 0, 2, sym6},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   STARTZERO,
-   },
-  {
-   FORMULAMAGIC,
-#ifndef SLOWFUNCPTR
-   barnsley2_calc,
-   NULL,
-   sbarnsley2_calc,
-   NULL,
-#endif
-   barnsley2_julia,
-   {"Barnsley2 Mandelbrot", "Barnsley2"},
-   "barnsley2",
-   /*{1.25, -1.25, 1.25, -1.25}, */
-   {0.0, 0.0, 2.5, 5.5},
-   0, 0, -0.6, 1.1,
-   {
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   {
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    {INT_MAX, INT_MAX, 0, NULL},
-    },
-   STARTZERO | MANDEL_BTRACE,
-   },
-  {
+  { /* formula added by Andreas Madritsch */
    FORMULAMAGIC,
 #ifndef SLOWFUNCPTR
    magnet2_calc,
@@ -1548,6 +1783,376 @@ CONST struct formula formulas[] = {
     },
    STARTZERO,
    },
+  { /* formula added by Arpad Fekete */
+   FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   trice_calc,
+   trice_peri,
+   strice_calc,
+   strice_peri,
+#endif
+   NULL,
+   {"Triceratops", "Triceratops Julia"},
+   "trice",
+   {0.0, 0.0, 2.5, 4.5},
+   1, 1, 0.0, 0.0,
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete */
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   catseye_calc,
+   catseye_peri,
+   scatseye_calc,
+   scatseye_peri,
+#endif
+   NULL,
+   {"Catseye", "Catseye Julia"},
+   "catseye",
+   {0.0, 0.0, 2.5, 4.5},
+   1, 1, 0.0, 0.0,
+   {
+    {0, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {0, 0, 0, NULL},
+    {0, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {0, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {0, 0, 0, NULL},
+    {0, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {0, 0, 0, NULL},
+    {0, 0, 0, NULL},
+    {0, 0, 0, NULL},
+    {0, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   MANDEL_BTRACE,
+   },
+   { /*formula added by Arpad Fekete*/
+     /*in Gnofract4d from mathworld.wolfram.com*/
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   mbar_calc,
+   mbar_peri,
+   smbar_calc,
+   smbar_peri,
+#endif
+   mbar_julia,
+   {"Mandelbar", "Mandelbar Julia"},
+   "mbar",
+   {0.0, 0.0, 2.5, 3.5},
+   1, 1, 0.0, 0.0,
+   {
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, 0, 2, sym6},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete (from fractint)*/
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   mlambda_calc,
+   mlambda_peri,
+   smlambda_calc,
+   smlambda_peri,
+#endif
+   NULL,
+   {"Lambda Mandelbrot", "Lambda"},
+   "mlambda",
+   {0.5, 0.0, 2.5, 5.5},
+   0, 0, 0.5, 0.0,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete (from fractint)*/
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   manowar_calc,
+   NULL,
+   smanowar_calc,
+   NULL,
+#endif
+   NULL,
+   {"Manowar", "Manowar Julia"},
+   "manowar",
+   {0.0, 0.0, 2.5, 2.5},
+   1, 1, 0.0, 0.0,
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete (from fractint)*/
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   spider_calc,
+   NULL,
+   sspider_calc,
+   NULL,
+#endif
+   NULL,
+   {"Spider", "Spider Julia"},
+   "spider",
+   {0.0, 0.0, 2.5, 4.5},
+   1, 1, 0.0, 0.0,
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, 0, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete, method from fractint */
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   sier_calc,
+   NULL,
+   NULL,
+   NULL,
+#endif
+   NULL,
+   {"Sierpinski", "Sierpinski"},
+   "sier",
+   {0.5, 0.43, 1.5, 1.0},
+   0, 0, 0.5, 0.8660254,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete, method from fractint */
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   carpet_calc,
+   NULL,
+   NULL,
+   NULL,
+#endif
+   NULL,
+   {"S.Carpet", "S.Carpet"},
+   "carpet",
+   {0.5, 0.5, 1.5, 1.5},
+   0, 0, 1, 1,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   },
+   { /* formula added by Arpad Fekete, method from fractint */
+    FORMULAMAGIC,
+#ifndef SLOWFUNCPTR
+   koch_calc,
+   NULL,
+   NULL,
+   NULL,
+#endif
+   NULL,
+   {"Koch Snowflake", "Koch Snowflake"},
+   "koch",
+   {0.0, 0.0, 2.5, 2.5},
+   0, 1, 0, 0,
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+   {
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    {INT_MAX, INT_MAX, 0, NULL},
+    },
+    MANDEL_BTRACE,
+   }   
 };
 
 #ifdef SLOWFUNCPTR
@@ -1558,7 +2163,7 @@ calculateswitch (register number_t x1, register number_t y1,
   if (periodicity && cfractalc.periodicity)
     if (cfractalc.coloringmode == 9)
       switch (cfractalc.currentformula - formulas)
-	{
+	{ /* periodicity checking and smoothmode SPERI */
 	case 0:
 	  return (smand_peri (x1, y1, x2, y2));
 	  break;
@@ -1575,33 +2180,63 @@ calculateswitch (register number_t x1, register number_t y1,
 	  return (smand6_peri (x1, y1, x2, y2));
 	  break;
 	case 5:
-	  return (octo_calc (x1, y1, x2, y2));
-	  break;
-	case 6:
 	  return (newton_calc (x1, y1, x2, y2));
 	  break;
+	case 6:
+	  return (newton4_calc (x1, y1, x2, y2));
+	  break;	  
 	case 7:
 	  return (sbarnsley1_calc (x1, y1, x2, y2));
 	  break;
 	case 8:
-	  return (sphoenix_peri (x1, y1, x2, y2));
-	  break;
-	case 9:
-	  return (smagnet_peri (x1, y1, x2, y2));
-	  break;
-	case 10:
-	  return (newton4_calc (x1, y1, x2, y2));
-	  break;
-	case 11:
 	  return (sbarnsley2_calc (x1, y1, x2, y2));
 	  break;
-	case 12:
-	  return (smagnet2_peri (x1, y1, x2, y2));
+	case 9:
+	  return (sbarnsley3_calc (x1, y1, x2, y2));
+	  break;	  
+	case 10:
+	  return (octo_calc (x1, y1, x2, y2));
+	  break;	  
+	case 11:
+	  return (sphoenix_peri (x1, y1, x2, y2));
 	  break;
+	case 12:
+	  return (smagnet_peri (x1, y1, x2, y2));
+	  break;
+	case 13:
+	  return (smagnet2_peri (x1, y1, x2, y2));
+	  break;	  	  
+	case 14:
+	  return (strice_peri (x1, y1, x2, y2));
+	  break;
+	case 15:
+	  return (scatseye_peri (x1, y1, x2, y2));
+	  break;	  
+	case 16:
+	  return (smbar_peri (x1, y1, x2, y2));
+	  break;
+	case 17:
+	  return (smlambda_peri (x1, y1, x2, y2));
+	  break;	  	
+	case 18:
+	  return (smanowar_calc (x1, y1, x2, y2));
+	  break;
+	case 19:
+	  return (sspider_calc (x1, y1, x2, y2));
+	  break;
+	case 20:
+	  return (sier_calc (x1, y1, x2, y2));
+	  break; 
+	case 21:
+	  return (carpet_calc (x1, y1, x2, y2));
+	  break; 
+	case 22:
+	  return (koch_calc (x1, y1, x2, y2));
+	  break; 	  	  	  	  	
 	}
     else
       switch (cfractalc.currentformula - formulas)
-	{
+	{ /* periodicity checking and no smoothmode PERI */
 	case 0:
 	  return (mand_peri (x1, y1, x2, y2));
 	  break;
@@ -1618,33 +2253,63 @@ calculateswitch (register number_t x1, register number_t y1,
 	  return (mand6_peri (x1, y1, x2, y2));
 	  break;
 	case 5:
-	  return (octo_calc (x1, y1, x2, y2));
-	  break;
-	case 6:
 	  return (newton_calc (x1, y1, x2, y2));
 	  break;
+	case 6:
+	  return (newton4_calc (x1, y1, x2, y2));
+	  break;	  
 	case 7:
 	  return (barnsley1_calc (x1, y1, x2, y2));
 	  break;
 	case 8:
-	  return (phoenix_peri (x1, y1, x2, y2));
+	  return (barnsley2_calc (x1, y1, x2, y2)); 
 	  break;
 	case 9:
-	  return (magnet_peri (x1, y1, x2, y2));
-	  break;
+	  return (barnsley3_calc (x1, y1, x2, y2)); 
+	  break;	  	  
 	case 10:
-	  return (newton4_calc (x1, y1, x2, y2));
-	  break;
+	  return (octo_calc (x1, y1, x2, y2));
+	  break;	  
 	case 11:
-	  return (sbarnsley2_calc (x1, y1, x2, y2));
+	  return (phoenix_peri (x1, y1, x2, y2));
 	  break;
 	case 12:
-	  return (smagnet2_peri (x1, y1, x2, y2));
+	  return (magnet_peri (x1, y1, x2, y2));
 	  break;
+	case 13:
+	  return (magnet2_peri (x1, y1, x2, y2)); 
+	  break;	  
+	case 14:
+	  return (trice_peri (x1, y1, x2, y2));
+	  break;
+	case 15:
+	  return (catseye_peri (x1, y1, x2, y2));
+	  break;	  
+	case 16:
+	  return (mbar_peri (x1, y1, x2, y2));
+	  break;
+	case 17:
+	  return (mlambda_peri (x1, y1, x2, y2));
+	  break;	  	  
+	case 18:
+	  return (manowar_calc (x1, y1, x2, y2));
+	  break;
+	case 19:
+	  return (spider_calc (x1, y1, x2, y2));
+	  break;
+	case 20:
+	  return (sier_calc (x1, y1, x2, y2));
+	  break;	
+	case 21:
+	  return (carpet_calc (x1, y1, x2, y2));
+	  break; 
+	case 22:
+	  return (koch_calc (x1, y1, x2, y2));
+	  break; 	  	    	  	  
 	}
   else if (cfractalc.coloringmode == 9)
     switch (cfractalc.currentformula - formulas)
-      {
+      { /* no periodicity checking and smoothmode SCALC */
       case 0:
 	return (smand_calc (x1, y1, x2, y2));
 	break;
@@ -1661,33 +2326,63 @@ calculateswitch (register number_t x1, register number_t y1,
 	return (smand6_calc (x1, y1, x2, y2));
 	break;
       case 5:
-	return (octo_calc (x1, y1, x2, y2));
+	return (newton_calc (x1, y1, x2, y2));
 	break;
       case 6:
-	return (newton_calc (x1, y1, x2, y2));
+	return (newton4_calc (x1, y1, x2, y2));
 	break;
       case 7:
 	return (sbarnsley1_calc (x1, y1, x2, y2));
 	break;
       case 8:
-	return (sphoenix_calc (x1, y1, x2, y2));
-	break;
+	return (sbarnsley2_calc (x1, y1, x2, y2));
+	break;	
       case 9:
-	return (smagnet_calc (x1, y1, x2, y2));
+        return (sbarnsley3_calc (x1, y1, x2, y2));
 	break;
       case 10:
-	return (newton4_calc (x1, y1, x2, y2));
+	return (socto_calc (x1, y1, x2, y2));
 	break;
       case 11:
-	return (sbarnsley2_calc (x1, y1, x2, y2));
+	return (sphoenix_calc (x1, y1, x2, y2));
 	break;
       case 12:
-	return (smagnet2_peri (x1, y1, x2, y2));
+	return (smagnet_calc (x1, y1, x2, y2));
 	break;
+      case 13:
+	return (smagnet2_calc (x1, y1, x2, y2)); 
+	break;
+      case 14:
+        return (strice_calc (x1, y1, x2, y2));
+	break;	
+      case 15:
+        return (scatseye_calc (x1, y1, x2, y2));
+	break;	
+      case 16:
+        return (smbar_calc (x1, y1, x2, y2));
+	break;	
+      case 17:
+        return (smlambda_calc (x1, y1, x2, y2));
+	break;	
+      case 18:
+	return (smanowar_calc (x1, y1, x2, y2));
+	break;	
+      case 19:
+	return (sspider_calc (x1, y1, x2, y2));
+	break;	
+      case 20:
+	return (sier_calc (x1, y1, x2, y2));
+	break;
+      case 21:
+	return (carpet_calc (x1, y1, x2, y2));
+	break; 	
+      case 22:
+	return (koch_calc (x1, y1, x2, y2));
+	break; 	
       }
   else
     switch (cfractalc.currentformula - formulas)
-      {
+      { /* no periodicity checking and no smoothmode CALC */
       case 0:
 	return (mand_calc (x1, y1, x2, y2));
 	break;
@@ -1704,29 +2399,59 @@ calculateswitch (register number_t x1, register number_t y1,
 	return (mand6_calc (x1, y1, x2, y2));
 	break;
       case 5:
-	return (octo_calc (x1, y1, x2, y2));
-	break;
-      case 6:
 	return (newton_calc (x1, y1, x2, y2));
 	break;
+      case 6:
+	return (newton4_calc (x1, y1, x2, y2));
+	break;	
       case 7:
 	return (barnsley1_calc (x1, y1, x2, y2));
 	break;
       case 8:
-	return (phoenix_calc (x1, y1, x2, y2));
+	return (barnsley2_calc (x1, y1, x2, y2)); 
 	break;
       case 9:
-	return (magnet_calc (x1, y1, x2, y2));
+        return (barnsley3_calc (x1, y1, x2, y2)); 
 	break;
       case 10:
-	return (newton4_calc (x1, y1, x2, y2));
+	return (octo_calc (x1, y1, x2, y2));
 	break;
       case 11:
-	return (sbarnsley2_calc (x1, y1, x2, y2));
+	return (phoenix_calc (x1, y1, x2, y2));
 	break;
       case 12:
-	return (smagnet2_peri (x1, y1, x2, y2));
+	return (magnet_calc (x1, y1, x2, y2));
 	break;
+      case 13:
+	return (magnet2_calc (x1, y1, x2, y2)); 
+	break;
+      case 14:
+        return (trice_calc (x1, y1, x2, y2));
+	break;
+      case 15:
+        return (catseye_calc (x1, y1, x2, y2));
+	break;		
+      case 16:
+        return (mbar_calc (x1, y1, x2, y2));
+	break;	
+      case 17:
+        return (mlambda_calc (x1, y1, x2, y2));
+	break;	
+      case 18:
+	return (manowar_calc (x1, y1, x2, y2));
+	break;	
+      case 19:
+	return (spider_calc (x1, y1, x2, y2));
+	break;	
+      case 20:
+        return (sier_calc (x1, y1, x2, y2));
+	break;	
+      case 21:
+	return (carpet_calc (x1, y1, x2, y2));
+	break; 	
+      case 22:
+	return (koch_calc (x1, y1, x2, y2));
+	break; 		
       }
   return 0;
 }
@@ -1734,3 +2459,4 @@ calculateswitch (register number_t x1, register number_t y1,
 
 CONST struct formula *currentformula;
 CONST int nformulas = sizeof (formulas) / sizeof (struct formula);
+CONST int nmformulas = 14;
