@@ -25,7 +25,13 @@
 #include <config.h>
 #include <zoom.h>
 
-#define PLANES 7
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
+
+/*#define PLANES 7*/
 #define P_MU 0
 #define P_INVERSE 1
 #define P_PARABOL 2
@@ -33,9 +39,11 @@
 #define P_INVLAMBDA 4
 #define P_TRANLAMBDA 5
 #define P_MEREBERG 6
-extern void 
-recalculate (int plane, number_t *, number_t *) 
-REGISTERS (3) CONSTF;
-     extern char *planename[];
+  extern void recalculate (int plane, number_t *, number_t *) REGISTERS (3);
 
-#endif /* PLANE_H */
+  extern CONST char *CONST planename[];
+
+#ifdef __cplusplus
+}
+#endif
+#endif				/* PLANE_H */
