@@ -290,7 +290,7 @@ static menudialog uih_perturbationdialog[] = {
 #ifdef DEBUG
   printf ("Filled %d widgets out of %d.\n",
 	  no_menudialogs_i18n, MAX_MENUDIALOGS_I18N);
-#endif	
+#endif
 }
 
 #undef Register
@@ -835,7 +835,7 @@ uih_persw (struct uih_context *c, number_t x, number_t y)
     uih_setperbutation (c, 0.0, 0.0);
   else
     uih_setperbutation (c, x, y);
-
+  printf(""); // fixme: some newer versions of gcc crashes without this
 }
 static int
 uih_perselected (struct uih_context *c)
@@ -1040,11 +1040,9 @@ uih_registermenus_i18n (void)
 	     "tutor") SUBMENUNOOPT_I ("animroot", "f", gettext ("File"),
 				      "file");
   MENUNOP_I ("animroot", "s", gettext ("Stop replay"), "stopreplay",
-	     UI | MENUFLAG_INTERRUPT,
-	     uih_replaydisable); SUBMENUNOOPT_I ("animroot", NULL,
-						gettext ("Help"),
-						"helpmenu");
-    SUBMENUNOOPT_I ("animroot", NULL, gettext ("UI"), "uia");
+	     UI | MENUFLAG_INTERRUPT, uih_replaydisable);
+  SUBMENUNOOPT_I ("animroot", NULL, gettext ("Help"), "helpmenu");
+  SUBMENUNOOPT_I ("animroot", NULL, gettext ("UI"), "uia");
   MENUDIALOG_I ("misc", "!", gettext ("Command"), "command", UI, uih_command,
 		dcommand);
   MENUDIALOG_I ("misc", NULL, gettext ("Play string"), "playstr",
@@ -1070,10 +1068,10 @@ uih_registermenus_i18n (void)
 		uih_playtextpos, uih_textposdialog);
   MENUDIALOG_I ("misc", NULL, gettext ("Message"), "message",
 		MENUFLAG_NOMENU, uih_playmessage, dtextparam);
-    /* The following 6 menu options should not be translated. The example
-       files heavily use these constants and lots of examples will not work
-       anymore... :-(  Anyway, this should be fixed somehow. */
-    
+  /* The following 6 menu options should not be translated. The example
+     files heavily use these constants and lots of examples will not work
+     anymore... :-(  Anyway, this should be fixed somehow. */
+
   MENUINTRB_I ("ytextpos", NULL, "Up", "ytextup", UI, uih_setytextpos,
 	       UIH_TEXTTOP, uih_ytextselected);
   MENUINTRB_I ("ytextpos",
@@ -1120,7 +1118,8 @@ uih_registermenus_i18n (void)
 	     "redo",
 	     MENUFLAG_INTERRUPT
 	     | MENUFLAG_NOPLAY | MENUFLAG_NOOPTION, uih_redo);
-  SUBMENU_I ("fractal", NULL, gettext ("formulae"), "mformula");
+  SUBMENU_I ("fractal", NULL, gettext ("Formulae"), "mformula");
+  SUBMENU_I ("fractal", NULL, gettext ("More formulae"), "oformula");
   MENUSEPARATOR_I ("fractal");
   SUBMENU_I ("fractal", "f", gettext ("Incoloring mode"), "mincoloring");
   SUBMENU_I ("fractal", "c", gettext ("Outcoloring mode"), "moutcoloring");
@@ -1319,6 +1318,7 @@ uih_registermenus_i18n (void)
   SUBMENU_I ("tutor", NULL, gettext ("An introduction to fractals"), "intro");
   SUBMENU_I ("tutor", NULL, gettext ("XaoS features overview"), "features");
   SUBMENU_I ("tutor", NULL, gettext ("Math behind fractals"), "fmath");
+  SUBMENU_I ("tutor", NULL, gettext ("Other fractal types in XaoS"), "otherf");
   SUBMENU_I ("tutor", NULL, gettext ("What's new?"), "new");
   /* Language selection is not sensible anymore if i18n is used: */
 #ifndef HAVE_GETTEXT
@@ -1356,11 +1356,16 @@ uih_registermenus_i18n (void)
   TUTOR_I ("fmath", gettext ("The definition and fractal dimension"),
 	   "dimension.xaf");
   TUTOR_I ("fmath", gettext ("Escape time fractals"), "escape.xaf");
+  TUTOR_I ("otherf", gettext ("Other fractal types in XaoS"), "otherfr.xaf");
+  MENUSEPARATOR_I ("otherf");
+  TUTOR_I ("otherf", gettext ("Triceratops and Catseye fractals"), "trice.xaf");
+  TUTOR_I ("otherf", gettext ("Mandelbar, Lambda, Manowar and Spider"), "fourfr.xaf");
+  TUTOR_I ("otherf", gettext ("Sierpinski Gasket, S.Carpet, Koch Snowflake"), "classic.xaf");
   TUTOR_I ("new", gettext ("What's new in 3.0?"), "new30.xaf");
 #ifdef DEBUG
   printf ("Filled %d menu items out of %d.\n", no_menuitems_i18n,
 	  MAX_MENUITEMS_I18N);
-#endif	 
+#endif
   menu_add (menuitems_i18n, no_menuitems_i18n);
   uih_no_menuitems_i18n = no_menuitems_i18n;
 }
@@ -1456,7 +1461,11 @@ uih_registermenus (void)
   keys = malloc (sizeof (*keys) * nformulas);
   for (i = 0; i < nformulas; i++)
     {
-      item[i].menuname = "mformula";
+      if (i < nmformulas) {
+        item[i].menuname = "mformula";
+      } else {
+        item[i].menuname = "oformula";
+      }
       item[i].key = keys[i];
       if (i < 9)
 	keys[i][0] = '1' + i;
