@@ -20,30 +20,29 @@
 
 #include <View.h>
 #include <Window.h>
+#include "XaoSEvent.h"
+#include "XaoSAbstractWindow.h"
 
-class XaoSWindow : public BWindow
+class XaoSWindow:public BWindow, XaoSAbstractWindow
 {
 public:
-	typedef BWindow inherited;
-	
-	// Constructor, destructor.
-	XaoSWindow(BView *const pView);
-	virtual ~XaoSWindow(void);
+  typedef BWindow inherited;
+
+  // Constructor, destructor.
+    XaoSWindow (BRect frame, port_id port);
+    virtual ~ XaoSWindow (void);
+
+  // Hook functions.
+  virtual void FrameResized (float width, float height);
+  virtual bool QuitRequested (void);
+  virtual void MessageReceived (BMessage * pMessage);
+
+  // Allow quit requests to succeed.
+  virtual void AllowQuit (void);
 
-	// Hook functions.
-	virtual void FrameResized(float width, float height);
-	virtual bool QuitRequested(void);
-	
-	// Allow quit requests to succeed.
-	void AllowQuit(void);
-	
 private:
-	XaoSWindow(const XaoSWindow &orig);
-	XaoSWindow &operator =(const XaoSWindow &orig);
-	
-	// Data members.
-	BView *const mpView;
-	bool mQuitAllowed;
+    XaoSWindow (const XaoSWindow & orig);
+    XaoSWindow & operator = (const XaoSWindow & orig);
 };
 
 #endif // XAOSWINDOW_H
